@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg with excerpts from portableaserve
 ;;;; Date Started:  Jun 2003
 ;;;;
-;;;; $Id: sockets.lisp 11204 2006-09-22 17:47:39Z kevin $
+;;;; $Id: sockets.lisp 11421 2006-12-31 18:42:10Z kevin $
 ;;;; *************************************************************************
 
 (in-package #:kmrcl)
@@ -27,26 +27,30 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
 			       :protocol :tcp)))
     (if reuse
         (setf (sb-bsd-sockets:sockopt-reuse-address socket) t))
-    (sb-bsd-sockets:socket-bind 
+    (sb-bsd-sockets:socket-bind
      socket (sb-bsd-sockets:make-inet-address "0.0.0.0") port)
     (sb-bsd-sockets:socket-listen socket 15)
     socket))
 
 (defun create-inet-listener (port &key (format :text) (reuse-address t))
+  #+cmu (declare (ignore format reuse-address))
   #+cmu (ext:create-inet-listener port)
   #+allegro
   (socket:make-socket :connect :passive :local-port port :format format
-		      :address-family 
+		      :address-family
 		      (if (stringp port)
 			  :file
 			(if (or (null port) (integerp port))
 			    :internet
 			  (error "illegal value for port: ~s" port)))
 		      :reuse-address reuse-address)
-  #+sbcl
-  (listen-to-inet-port :port port :reuse reuse-address)
+  #+sbcl (declare (ignore format))
+  #+sbcl (listen-to-inet-port :port port :reuse reuse-address)
+  #+clisp (declare (ignore format reuse-address))
   #+clisp (ext:socket-server port)
-  #+openmcl 
+  #+openmcl
+  (declare (ignore format))
+  #+openmcl
   (ccl:make-socket :connect :passive :local-port port
 		   :reuse-address reuse-address)
   #-(or allegro clisp cmu sbcl openmcl)
@@ -86,7 +90,7 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
        (sb-bsd-sockets:socket-make-stream
 	sock :element-type :default :input t :output t)
        sock)))
-  #+openmcl 
+  #+openmcl
   (let ((sock (ccl:accept-connection listener :wait t)))
     (values sock sock))
   #-(or allegro clisp cmu sbcl openmcl)
@@ -134,15 +138,15 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
   (declare (string dotted))
   (if errorp
       (let ((ll (delimited-string-to-list dotted #\.)))
-	(+ (ash (parse-integer (first ll)) 24) 
+	(+ (ash (parse-integer (first ll)) 24)
 	   (ash (parse-integer (second ll)) 16)
-	   (ash (parse-integer (third ll)) 8) 
+	   (ash (parse-integer (third ll)) 8)
 	   (parse-integer (fourth ll))))
     (ignore-errors
       (let ((ll (delimited-string-to-list dotted #\.)))
 	(+ (ash (parse-integer (first ll)) 24)
 	   (ash (parse-integer (second ll)) 16)
-	   (ash (parse-integer (third ll)) 8) 
+	   (ash (parse-integer (third ll)) 8)
 	   (parse-integer (fourth ll)))))))
 
 #+sbcl
@@ -197,13 +201,13 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
 (defun ipaddr-array-to-dotted (array)
   (format nil "~{~D~^.~}" (coerce array 'list))
   #+ignore
-  (format nil "~D.~D.~D.~D" 
+  (format nil "~D.~D.~D.~D"
 	  (aref 0 array) (aref 1 array) (aref 2 array) (array 3 array)))
 
 (defun remote-host (socket)
   #+allegro (socket:ipaddr-to-dotted (socket:remote-host socket))
   #+lispworks (nth-value 0 (comm:get-socket-peer-address socket))
-  #+sbcl (ipaddr-array-to-dotted 
+  #+sbcl (ipaddr-array-to-dotted
 	  (nth-value 0 (sb-bsd-sockets:socket-peername socket)))
   #+cmu (nth-value 0 (ext:get-peer-host-and-port socket))
   #+clisp (let* ((peer (ext:socket-stream-peer socket t))
@@ -212,4 +216,4 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
            (if stop (subseq peer 0 stop) peer))
   #+openmcl (ccl:remote-host socket)
   )
-  
+
